# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import date, datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "SensorListResponse",
    "Entity",
    "EntityLocation",
    "EntityOnOrbit",
    "Sensorcharacteristic",
    "SensorlimitsCollection",
    "SensorObservationType",
    "SensorStat",
    "SensorType",
]


class EntityLocation(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Location name."""

    source: str
    """Source of the data."""

    altitude: Optional[float] = None
    """Altitude of the location, in kilometers."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """Unique identifier of the location, auto-generated by the system."""

    lat: Optional[float] = None
    """WGS84 latitude of the location, in degrees.

    -90 to 90 degrees (negative values south of equator).
    """

    lon: Optional[float] = None
    """WGS84 longitude of the location, in degrees.

    -180 to 180 degrees (negative values west of Prime Meridian).
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """


class EntityOnOrbit(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    sat_no: int = FieldInfo(alias="satNo")
    """Satellite/Catalog number of the target on-orbit object."""

    source: str
    """Source of the data."""

    alt_name: Optional[str] = FieldInfo(alias="altName", default=None)
    """Alternate name of the on-orbit object."""

    category: Optional[
        Literal[
            "Unknown",
            "On-Orbit",
            "Decayed",
            "Cataloged Without State",
            "Launch Nominal",
            "Analyst Satellite",
            "Cislunar",
            "Lunar",
            "Hyperbolic",
            "Heliocentric",
            "Interplanetary",
            "Lagrangian",
            "Docked",
        ]
    ] = None
    """Category of the on-orbit object.

    (Unknown, On-Orbit, Decayed, Cataloged Without State, Launch Nominal, Analyst
    Satellite, Cislunar, Lunar, Hyperbolic, Heliocentric, Interplanetary,
    Lagrangian, Docked).
    """

    common_name: Optional[str] = FieldInfo(alias="commonName", default=None)
    """Common name of the on-orbit object."""

    constellation: Optional[str] = None
    """Constellation to which this satellite belongs."""

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    decay_date: Optional[datetime] = FieldInfo(alias="decayDate", default=None)
    """Date of decay."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """
    For the public catalog, the idOnOrbit is typically the satellite number as a
    string, but may be a UUID for analyst or other unknown or untracked satellites,
    auto-generated by the system.
    """

    intl_des: Optional[str] = FieldInfo(alias="intlDes", default=None)
    """
    International Designator, typically of the format YYYYLLLAAA, where YYYY is the
    launch year, LLL is the sequential launch number of that year, and AAA is an
    optional launch piece designator for the launch.
    """

    launch_date: Optional[date] = FieldInfo(alias="launchDate", default=None)
    """Date of launch."""

    launch_site_id: Optional[str] = FieldInfo(alias="launchSiteId", default=None)
    """Id of the associated launchSite entity."""

    lifetime_years: Optional[int] = FieldInfo(alias="lifetimeYears", default=None)
    """Estimated lifetime of the on-orbit payload, if known."""

    mission_number: Optional[str] = FieldInfo(alias="missionNumber", default=None)
    """Mission number of the on-orbit object."""

    object_type: Optional[Literal["ROCKET BODY", "DEBRIS", "PAYLOAD", "PLATFORM", "MANNED", "UNKNOWN"]] = FieldInfo(
        alias="objectType", default=None
    )
    """
    Type of on-orbit object: ROCKET BODY, DEBRIS, PAYLOAD, PLATFORM, MANNED,
    UNKNOWN.
    """

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """


class Entity(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    name: str
    """Unique entity name."""

    source: str
    """Source of the data."""

    type: Literal[
        "AIRCRAFT",
        "BUS",
        "COMM",
        "IR",
        "LASEREMITTER",
        "NAVIGATION",
        "ONORBIT",
        "RFEMITTER",
        "SCIENTIFIC",
        "SENSOR",
        "SITE",
        "VESSEL",
    ]
    """
    The type of entity represented by this record (AIRCRAFT, BUS, COMM, IR,
    LASEREMITTER, NAVIGATION, ONORBIT, RFEMITTER, SCIENTIFIC, SENSOR, SITE, VESSEL).
    """

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)
    """The country code.

    This value is typically the ISO 3166 Alpha-2 two-character country code, however
    it can also represent various consortiums that do not appear in the ISO
    document. The code must correspond to an existing country in the UDL’s country
    API. Call udl/country/{code} to get any associated FIPS code, ISO Alpha-3 code,
    or alternate code values that exist for the specified country code.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_entity: Optional[str] = FieldInfo(alias="idEntity", default=None)
    """Unique identifier of the record."""

    id_location: Optional[str] = FieldInfo(alias="idLocation", default=None)
    """Unique identifier of the entity location, if terrestrial/fixed."""

    id_on_orbit: Optional[str] = FieldInfo(alias="idOnOrbit", default=None)
    """Onorbit identifier if this entity is part of an on-orbit object.

    For the public catalog, the idOnOrbit is typically the satellite number as a
    string, but may be a UUID for analyst or other unknown or untracked satellites.
    """

    id_operating_unit: Optional[str] = FieldInfo(alias="idOperatingUnit", default=None)
    """Unique identifier of the associated operating unit object."""

    location: Optional[EntityLocation] = None
    """
    Model representation of a location, which is a specific fixed point on the earth
    and is used to denote the locations of fixed sensors, operating units, etc.
    """

    on_orbit: Optional[EntityOnOrbit] = FieldInfo(alias="onOrbit", default=None)
    """Model object representing on-orbit objects or satellites in the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    owner_type: Optional[Literal["Commercial", "Government", "Academic", "Consortium", "Other"]] = FieldInfo(
        alias="ownerType", default=None
    )
    """Type of organization which owns this entity (e.g.

    Commercial, Government, Academic, Consortium, etc).
    """

    taskable: Optional[bool] = None
    """Boolean indicating if this entity is taskable."""

    terrestrial_id: Optional[str] = FieldInfo(alias="terrestrialId", default=None)
    """Terrestrial identifier of this entity, if applicable."""


class Sensorcharacteristic(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sensor: str = FieldInfo(alias="idSensor")
    """Unique identifier of the parent sensor."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    accept_sample_ranges: Optional[List[float]] = FieldInfo(alias="acceptSampleRanges", default=None)
    """Array of measurement range(s) where radar samples must fall to be acceptable.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    analog_to_digital_bit_size: Optional[int] = FieldInfo(alias="analogToDigitalBitSize", default=None)
    """
    Number of bits used in the conversion from analog electrons in a pixel well to a
    digital number. The digital number has a maximum value of 2^N, where N is the
    number of bits.
    """

    aperture: Optional[float] = None
    """Optical sensor camera aperture."""

    asr_scan_rate: Optional[float] = FieldInfo(alias="asrScanRate", default=None)
    """
    For ASR (Air Surveillance Radar) sensors, the scan (360 deg sweep) rate of the
    radar, in scans/minute.
    """

    atmos_receiver_loss: Optional[float] = FieldInfo(alias="atmosReceiverLoss", default=None)
    """One-way radar receiver loss factor due to atmospheric effects.

    This value will often be the same as the corresponding transmission factor but
    may be different for bistatic systems.
    """

    atmos_transmission_loss: Optional[float] = FieldInfo(alias="atmosTransmissionLoss", default=None)
    """One-way radar transmission loss factor due to atmospheric effects."""

    avg_atmos_seeing_conditions: Optional[float] = FieldInfo(alias="avgAtmosSeeingConditions", default=None)
    """
    Average atmospheric angular width with no distortion from turbulence at an
    optical sensor site in arcseconds.
    """

    az_angs: Optional[List[float]] = FieldInfo(alias="azAngs", default=None)
    """Array of azimuth angles of a radar beam, in degrees.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    azimuth_rate: Optional[float] = FieldInfo(alias="azimuthRate", default=None)
    """Azimuth rate acquisition limit (radians/minute)."""

    background_sky_radiance: Optional[float] = FieldInfo(alias="backgroundSkyRadiance", default=None)
    """
    Average background sky brightness at an optical sensor site during new moon
    conditions. This field uses units of watts per square meter per steradian
    (W/(m^2 str)) consistent with sensor detection bands.
    """

    background_sky_vis_mag: Optional[float] = FieldInfo(alias="backgroundSkyVisMag", default=None)
    """
    Average background sky brightness at an optical sensor site during new moon
    conditions. This field uses units of visual magnitude consistent with sensor
    detection bands.
    """

    band: Optional[str] = None
    """Sensor band."""

    bandwidth: Optional[float] = None
    """The total bandwidth, in megahertz, about the radar center frequency."""

    beam_order: Optional[List[str]] = FieldInfo(alias="beamOrder", default=None)
    """Array designating the beam order of provided values (e.g.

    vb1 for vertical beam 1, ob1 for oblique beam 1, etc.). Required if any of the
    following array fields are populated: azAngs, elAngs, radarPulseWidths,
    pulseRepPeriods, delayGates, rangeGates, rangeSpacings, vertGateSpacings,
    vertGateWidths, specAvgSpectraNums, tempMedFiltCodes, runMeanCodes, totRecNums,
    reqRecords, acceptSampleRanges.
    """

    beam_qty: Optional[int] = FieldInfo(alias="beamQty", default=None)
    """Number of radar beams used by the sensor."""

    boresight: Optional[float] = None
    """The angle of the center of a phased array sensor."""

    boresight_off_angle: Optional[float] = FieldInfo(alias="boresightOffAngle", default=None)
    """The number of degrees off of the boresight for the sensor."""

    center_wavelength: Optional[float] = FieldInfo(alias="centerWavelength", default=None)
    """Weighted center wavelength for an optical sensor bandpass in micrometers.

    It is the center wavelength in a weighted integral sense, accounting for the
    sensitivity vs. wavelength curve for the sensor focal plane array.
    """

    collapsing_loss: Optional[float] = FieldInfo(alias="collapsingLoss", default=None)
    """Collapsing loss in decibels.

    Collapsing losses occur when two or more sources of noise are added to the
    target signal. Examples include receiver bandwidth mismatch with filtering
    bandwidth and elevation or azimuth beam collapse onto position/height indicator
    displays.
    """

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    crit_shear: Optional[float] = FieldInfo(alias="critShear", default=None)
    """
    Threshold shear value beyond which one of the radial velocity values will be
    rejected, measured in units of inverse second.
    """

    dark_current: Optional[float] = FieldInfo(alias="darkCurrent", default=None)
    """
    Current flowing through optical sensor focal plane electronics with a closed
    shutter in electrons per second.
    """

    delay_gates: Optional[List[float]] = FieldInfo(alias="delayGates", default=None)
    """
    Array of time delay(s) for pulses from a radar beam to get to the first range
    gate, in nanoseconds. If this field is populated, the associated beam(s) must be
    provided in the beamOrder field.
    """

    description: Optional[str] = None
    """Description of the equipment and data source."""

    detect_snr: Optional[float] = FieldInfo(alias="detectSNR", default=None)
    """Detection signal-to-noise ratio (SNR) threshold in decibels.

    This value is typically lower than trackSNR.
    """

    duty_cycle: Optional[float] = FieldInfo(alias="dutyCycle", default=None)
    """Sensor duty cycle as a fraction of 1.

    Duty cycle is the fraction of time a sensor is actively transmitting.
    """

    earth_limb_excl_hgt: Optional[float] = FieldInfo(alias="earthLimbExclHgt", default=None)
    """
    Sensor Earth limb exclusion height in kilometers and is generally only applied
    to space-based sensors. Some models used an earth exclusion angle instead, but
    this assumes the sensor is in a circular orbit with constant altitude relative
    to the earth. The limb exclusion height can be used for space-based sensors in
    any orbit (assuming it is constant with sensor altitude). The limb height is
    defined to be 0 at the surface of the earth.
    """

    el_angs: Optional[List[float]] = FieldInfo(alias="elAngs", default=None)
    """Array of elevation angles of a radar beam, in degrees.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    elevation_rate_geolm: Optional[float] = FieldInfo(alias="elevationRateGeolm", default=None)
    """Elevation rate acquisition limit (radians/minute)."""

    equipment_type: Optional[str] = FieldInfo(alias="equipmentType", default=None)
    """Type of equipment used to take measurements."""

    fan_beam_width: Optional[float] = FieldInfo(alias="fanBeamWidth", default=None)
    """The beam width of a Sensor's Fan (range).

    The values for this range from (0.0 to PI).
    """

    fft: Optional[int] = None
    """
    Number of Fast Fourier Transform (FFT) points used to convert time varying
    signals into the frequency domain.
    """

    fgp_crit: Optional[int] = FieldInfo(alias="fgpCrit", default=None)
    """
    Maximum number of times the first guess was propagated in each gate before
    failing the first guess check.
    """

    filter_mismatch_factor: Optional[float] = FieldInfo(alias="filterMismatchFactor", default=None)
    """
    Noise term, in decibels, that arises when a radar receiver filter has a
    non-optimal bandwidth for an incoming signal (i.e., when it does not match the
    pulse width).
    """

    f_num: Optional[float] = FieldInfo(alias="fNum", default=None)
    """F-number for an optical telescope.

    It is dimensionless and is defined as the ratio of the focal length to the
    aperture width.
    """

    focal_point: Optional[float] = FieldInfo(alias="focalPoint", default=None)
    """
    For radar based sensors, the focal point elevation of the radar at the site, in
    meters.
    """

    h_fov: Optional[float] = FieldInfo(alias="hFOV", default=None)
    """Horizontal field of view, in degrees."""

    h_res_pixels: Optional[int] = FieldInfo(alias="hResPixels", default=None)
    """Horizontal pixel resolution."""

    k: Optional[float] = None
    """
    For radar based sensors, K-factor is a relative indicator of refractivity that
    infers the amount of radar beam bending due to atmosphere. (1<K<2).
    """

    left_clock_angle: Optional[float] = FieldInfo(alias="leftClockAngle", default=None)
    """For Orbiting Sensors, First Card Azimuth limit #1 (left, degrees)."""

    left_geo_belt_limit: Optional[float] = FieldInfo(alias="leftGeoBeltLimit", default=None)
    """Leftmost GEO belt longitude limit for this sensor (if applicable)."""

    location: Optional[str] = None
    """Site where measurement is taken."""

    loop_gain: Optional[float] = FieldInfo(alias="loopGain", default=None)
    """Aggregated radar range equation gain in decibels for maximum sensitivity.

    It is a roll-up value for low fidelity modeling and is often the only
    sensitivity value available for a radar system without access to detailed
    performance parameters.
    """

    lunar_excl_angle: Optional[float] = FieldInfo(alias="lunarExclAngle", default=None)
    """
    Lowest aspect angle of the full moon in degrees at which the sensor can achieve
    full performance.
    """

    mag_dec: Optional[float] = FieldInfo(alias="magDec", default=None)
    """Angle between magnetic north and true north at the sensor site, in degrees."""

    magnitude_limit: Optional[float] = FieldInfo(alias="magnitudeLimit", default=None)
    """Absolute magnitude acquisition limit for optical sensors."""

    max_deviation_angle: Optional[float] = FieldInfo(alias="maxDeviationAngle", default=None)
    """Max deviation angle of the sensor in degrees."""

    max_integration_time: Optional[float] = FieldInfo(alias="maxIntegrationTime", default=None)
    """Maximum integration time per image frame in seconds for an optical sensor."""

    max_observable_range: Optional[float] = FieldInfo(alias="maxObservableRange", default=None)
    """Maximum observable sensor range, in kilometers."""

    max_range_limit: Optional[float] = FieldInfo(alias="maxRangeLimit", default=None)
    """
    Maximum observable range limit in kilometers -- sensor cannot acquire beyond
    this range.
    """

    max_wavelength: Optional[float] = FieldInfo(alias="maxWavelength", default=None)
    """Maximum wavelength detectable by an optical sensor in micrometers."""

    min_integration_time: Optional[float] = FieldInfo(alias="minIntegrationTime", default=None)
    """Minimum integration time per image frame in seconds for an optical sensor."""

    min_range_limit: Optional[float] = FieldInfo(alias="minRangeLimit", default=None)
    """Minimum range measurement capability of the sensor, in kilometers."""

    min_signal_noise_ratio: Optional[float] = FieldInfo(alias="minSignalNoiseRatio", default=None)
    """Signal to Noise Ratio, in decibels.

    The values for this range from 0.0 - + 99.99 dB.
    """

    min_wavelength: Optional[float] = FieldInfo(alias="minWavelength", default=None)
    """Minimum wavelength detectable by an optical sensor in micrometers."""

    negative_range_rate_limit: Optional[float] = FieldInfo(alias="negativeRangeRateLimit", default=None)
    """Negative Range-rate/relative velocity limit (kilometers/second)."""

    noise_figure: Optional[float] = FieldInfo(alias="noiseFigure", default=None)
    """Noise figure for a radar system in decibels.

    This value may be used to compute system noise when the system temperature is
    unavailable.
    """

    non_coherent_integrated_pulses: Optional[int] = FieldInfo(alias="nonCoherentIntegratedPulses", default=None)
    """
    Number of pulses that are non-coherently integrated during detection processing.
    """

    num_integrated_pulses: Optional[int] = FieldInfo(alias="numIntegratedPulses", default=None)
    """For radar based sensors, number of integrated pulses in a transmit cycle."""

    num_integration_frames: Optional[int] = FieldInfo(alias="numIntegrationFrames", default=None)
    """Number of integration frames for an optical sensor."""

    num_optical_integration_modes: Optional[int] = FieldInfo(alias="numOpticalIntegrationModes", default=None)
    """The number of optical integration mode characteristics provided in this record.

    If provided, the numOpticalIntegrationModes value indicates the number of
    elements in each of the opticalIntegrationTimes, opticalIntegrationAngularRates,
    opticalIntegrationFrames, opticalIntegrationPixelBinnings, and
    opticalIntegrationSNRs arrays.
    """

    num_waveforms: Optional[int] = FieldInfo(alias="numWaveforms", default=None)
    """The number of waveforms characteristics provided in this record.

    If provided, the numWaveforms value indicates the number of elements in each of
    the waveformPulseWidths, waveformBandWidths, waveformMinRanges,
    waveformMaxRanges, and waveformLoopGains arrays.
    """

    optical_integration_angular_rates: Optional[List[float]] = FieldInfo(
        alias="opticalIntegrationAngularRates", default=None
    )
    """
    Array containing the angular rate, in arcsec/sec, for each provided optical
    integration mode. The number of elements must be equal to the value indicated in
    numOpticalIntegrationModes.
    """

    optical_integration_frames: Optional[List[float]] = FieldInfo(alias="opticalIntegrationFrames", default=None)
    """Array containing the number of frames, for each optical integration mode.

    The number of elements must be equal to the value indicated in
    numOpticalIntegrationModes.
    """

    optical_integration_pixel_binnings: Optional[List[float]] = FieldInfo(
        alias="opticalIntegrationPixelBinnings", default=None
    )
    """Array containing the pixel binning, for each optical integration mode.

    The number of elements must be equal to the value indicated in
    numOpticalIntegrationModes.
    """

    optical_integration_sn_rs: Optional[List[float]] = FieldInfo(alias="opticalIntegrationSNRs", default=None)
    """Array of optical integration modes signal to noise ratios.

    The number of elements must be equal to the value indicated in
    numOpticalIntegrationModes.
    """

    optical_integration_times: Optional[List[float]] = FieldInfo(alias="opticalIntegrationTimes", default=None)
    """
    Array containing the time, in seconds, for each provided optical integration
    mode. The number of elements must be equal to the value indicated in
    numOpticalIntegrationModes.
    """

    optical_transmission: Optional[float] = FieldInfo(alias="opticalTransmission", default=None)
    """Fraction of incident light transmitted to an optical sensor focal plane array.

    The value is given as a fraction of 1, not as a percent.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    pattern_absorption_loss: Optional[float] = FieldInfo(alias="patternAbsorptionLoss", default=None)
    """Two-way pattern absorption/propagation loss due to medium in decibels."""

    pattern_scan_loss: Optional[float] = FieldInfo(alias="patternScanLoss", default=None)
    """Losses from the beam shape, scanning, and pattern factor in decibels.

    These losses occur when targets are not directly in line with a beam center. For
    space surveillance, this will occur most often during sensor scanning.
    """

    peak_power: Optional[float] = FieldInfo(alias="peakPower", default=None)
    """
    Maximum instantaneous radar transmit power in watts for use in the radar range
    equation.
    """

    pixel_instantaneous_fov: Optional[float] = FieldInfo(alias="pixelInstantaneousFOV", default=None)
    """
    Angular field-of-view covered by one pixel in a focal plane array in
    microradians. The pixel is assumed to be a perfect square so that only a single
    value is required.
    """

    pixel_well_depth: Optional[int] = FieldInfo(alias="pixelWellDepth", default=None)
    """
    Maximum number of electrons that can be collected in a single pixel on an
    optical sensor focal plane array.
    """

    positive_range_rate_limit: Optional[float] = FieldInfo(alias="positiveRangeRateLimit", default=None)
    """Positive Range-rate/relative velocity limit (kilometers/second)."""

    prf: Optional[float] = None
    """For radar based sensors, pulse repetition frequency (PRF), in hertz.

    Number of new pulses transmitted per second.
    """

    prob_detect_snr: Optional[float] = FieldInfo(alias="probDetectSNR", default=None)
    """Designated probability of detection at the signal-to-noise detection threshold."""

    prob_false_alarm: Optional[float] = FieldInfo(alias="probFalseAlarm", default=None)
    """
    For radar based sensors, probability of the indication of the presence of a
    radar target due to noise or interference.
    """

    pulse_rep_periods: Optional[List[float]] = FieldInfo(alias="pulseRepPeriods", default=None)
    """
    Array of interval(s) between the start of one radar pulse and the start of
    another for a radar beam, in microseconds. If this field is populated, the
    associated beam(s) must be provided in the beamOrder field.
    """

    quantum_eff: Optional[float] = FieldInfo(alias="quantumEff", default=None)
    """Fraction of incident photons converted to electrons at the focal plane array.

    This value is a decimal number between 0 and 1, inclusive.
    """

    radar_frequency: Optional[float] = FieldInfo(alias="radarFrequency", default=None)
    """Radar frequency in hertz, of the sensor (if a radar sensor)."""

    radar_message_format: Optional[str] = FieldInfo(alias="radarMessageFormat", default=None)
    """Message data format transmitted by the sensor digitizer."""

    radar_mur: Optional[float] = FieldInfo(alias="radarMUR", default=None)
    """For radar based sensors, radar maximum unambiguous range, in kilometers."""

    radar_pulse_widths: Optional[List[float]] = FieldInfo(alias="radarPulseWidths", default=None)
    """Array of transmit time(s) for a radar beam pulse, in microseconds.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    radio_frequency: Optional[float] = FieldInfo(alias="radioFrequency", default=None)
    """Radio frequency (if sensor is RF)."""

    radome_loss: Optional[float] = FieldInfo(alias="radomeLoss", default=None)
    """
    Losses due to the presence of a protective radome surrounding a radar sensor, in
    decibels.
    """

    range_gates: Optional[List[int]] = FieldInfo(alias="rangeGates", default=None)
    """
    Array of the number(s) of discrete altitudes where return signals are sampled by
    a radar beam. If this field is populated, the associated beam(s) must be
    provided in the beamOrder field.
    """

    range_spacings: Optional[List[float]] = FieldInfo(alias="rangeSpacings", default=None)
    """Array of range gate spacing(s) for a radar beam, in nanoseconds.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    read_noise: Optional[int] = FieldInfo(alias="readNoise", default=None)
    """
    Number of false-signal electrons generated by optical sensor focal plane
    read-out electronics from photon-to-electron conversion during frame
    integration. The units are in electrons RMS.
    """

    receive_gain: Optional[float] = FieldInfo(alias="receiveGain", default=None)
    """Radar receive gain in decibels."""

    receive_horiz_beam_width: Optional[float] = FieldInfo(alias="receiveHorizBeamWidth", default=None)
    """Horizontal/azimuthal receive beamwidth for a radar in degrees."""

    receive_loss: Optional[float] = FieldInfo(alias="receiveLoss", default=None)
    """Aggregate radar receive loss, in decibels."""

    receive_vert_beam_width: Optional[float] = FieldInfo(alias="receiveVertBeamWidth", default=None)
    """Vertical/elevation receive beamwidth for a radar in degrees."""

    ref_temp: Optional[float] = FieldInfo(alias="refTemp", default=None)
    """Reference temperature for radar noise in Kelvin.

    A reference temperature is used when the radar system temperature is unknown and
    is combined with the system noise figure to estimate signal loss.
    """

    req_records: Optional[List[int]] = FieldInfo(alias="reqRecords", default=None)
    """
    Array of the total number(s) of records required to meet consensus for a radar
    beam. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    right_clock_angle: Optional[float] = FieldInfo(alias="rightClockAngle", default=None)
    """For Orbiting Sensors, First Card Azimuth limit #3 (right, degrees)."""

    right_geo_belt_limit: Optional[float] = FieldInfo(alias="rightGeoBeltLimit", default=None)
    """Rightmost GEO belt longitude limit for this sensor (if applicable)."""

    run_mean_codes: Optional[List[int]] = FieldInfo(alias="runMeanCodes", default=None)
    """Array of running mean code(s) used by radar data processing.

    The running mean method involves taking a series of averages of different
    selections of the full data set to smooth out short-term fluctuations in the
    data. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    signal_processing_loss: Optional[float] = FieldInfo(alias="signalProcessingLoss", default=None)
    """Radar signal processing losses, in decibels."""

    site_code: Optional[str] = FieldInfo(alias="siteCode", default=None)
    """Site code of the sensor."""

    solar_excl_angle: Optional[float] = FieldInfo(alias="solarExclAngle", default=None)
    """Sensor and target position vector origins are at the center of the earth.

    The sun vector origin is at the target position and points toward the sun. Any
    value between 0 and 180 degrees is acceptable and is assumed to apply in both
    directions (i.e., a solar exclusion angle of 30 degrees is understood to mean no
    viewing for any angle between -30 deg and +30 deg).
    """

    spec_avg_spectra_nums: Optional[List[int]] = FieldInfo(alias="specAvgSpectraNums", default=None)
    """
    Array of the number(s) of Doppler spectra used to process measurements from
    radar. Spectral averaging involves combining multiple Doppler spectra acquired
    to obtain a more accurate and representative spectrum. If this field is
    populated, the associated beam(s) must be provided in the beamOrder field.
    """

    system_noise_temperature: Optional[float] = FieldInfo(alias="systemNoiseTemperature", default=None)
    """
    For radar based sensors, expression of the radar system noise, aggregated as an
    equivalent thermal noise value, in degrees Kelvin.
    """

    taskable_range: Optional[float] = FieldInfo(alias="taskableRange", default=None)
    """Maximum taskable range of the sensor, in kilometers."""

    temp_med_filt_codes: Optional[List[int]] = FieldInfo(alias="tempMedFiltCodes", default=None)
    """Array of temporal median filter code(s) of a radar beam.

    Temporal median filtering is a noise-reducing algorithm which involves replacing
    each data point with the median value of a window of neighboring points over
    time. If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    test_number: Optional[str] = FieldInfo(alias="testNumber", default=None)
    """Test number for the observed measurement."""

    tot_rec_nums: Optional[List[int]] = FieldInfo(alias="totRecNums", default=None)
    """Array of the total number(s) of records for a radar beam.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    tower_height: Optional[float] = FieldInfo(alias="towerHeight", default=None)
    """For tower sensors, the physical height of the sensor tower, in meters."""

    track_angle: Optional[float] = FieldInfo(alias="trackAngle", default=None)
    """Beginning track angle limit, in radians.

    Track angle is the angle between the camera axis and the gimbal plane. Values
    range from 0 - PI/2.
    """

    track_snr: Optional[float] = FieldInfo(alias="trackSNR", default=None)
    """Track signal-to-noise ratio (SNR) threshold in decibels.

    This value is typically higher than detectSNR.
    """

    transmit_gain: Optional[float] = FieldInfo(alias="transmitGain", default=None)
    """Radar transmit gain in decibels."""

    transmit_horiz_beam_width: Optional[float] = FieldInfo(alias="transmitHorizBeamWidth", default=None)
    """Horizontal/azimuthal transmit beamwidth for a radar in degrees."""

    transmit_loss: Optional[float] = FieldInfo(alias="transmitLoss", default=None)
    """Aggregate radar transmit loss, in decibels."""

    transmit_power: Optional[float] = FieldInfo(alias="transmitPower", default=None)
    """Radar transmit power in Watts."""

    transmit_vert_beam_width: Optional[float] = FieldInfo(alias="transmitVertBeamWidth", default=None)
    """Vertical/elevation transmit beamwidth for a radar in degrees."""

    true_north_corrector: Optional[int] = FieldInfo(alias="trueNorthCorrector", default=None)
    """True North correction for the sensor, in ACP (Azimunth Change Pulse) count."""

    true_tilt: Optional[float] = FieldInfo(alias="trueTilt", default=None)
    """Antenna true tilt, in degrees."""

    twilight_angle: Optional[float] = FieldInfo(alias="twilightAngle", default=None)
    """Twilight angle for ground-based optical sensors in degrees.

    A sensor cannot view targets until the sun is below the twilight angle relative
    to the local horizon. The sign of the angle is positive despite the sun
    elevation being negative after local sunset. Typical values for the twilight
    angle are civil twilight (6 degrees), nautical twilight (12 degrees), and
    astronomical twilight (18 degrees).
    """

    vert_beam_flag: Optional[bool] = FieldInfo(alias="vertBeamFlag", default=None)
    """Flag indicating if a vertical radar beam was used in the wind calculation."""

    vert_gate_spacings: Optional[List[float]] = FieldInfo(alias="vertGateSpacings", default=None)
    """
    Array of vertical distance(s) between points where radar measurements are taken,
    in meters. If this field is populated, the associated beam(s) must be provided
    in the beamOrder field.
    """

    vert_gate_widths: Optional[List[float]] = FieldInfo(alias="vertGateWidths", default=None)
    """Array of width(s) of each location where radar measurements are taken, in
    meters.

    If this field is populated, the associated beam(s) must be provided in the
    beamOrder field.
    """

    v_fov: Optional[float] = FieldInfo(alias="vFOV", default=None)
    """Vertical field of view, in degrees."""

    v_res_pixels: Optional[int] = FieldInfo(alias="vResPixels", default=None)
    """Vertical pixel resolution."""

    waveform_bandwidths: Optional[List[float]] = FieldInfo(alias="waveformBandwidths", default=None)
    """Array containing the bandwidth, in megahertz, for each provided waveform.

    The number of elements in this array must be equal to the value indicated in the
    numWaveforms field.
    """

    waveform_loop_gains: Optional[List[float]] = FieldInfo(alias="waveformLoopGains", default=None)
    """Array containing the loop gain, in decibels, for each provided waveform.

    The number of elements in this array must be equal to the value indicated in the
    numWaveforms field (10 SNR vs. 1 dBsm at 1000 km).
    """

    waveform_max_ranges: Optional[List[float]] = FieldInfo(alias="waveformMaxRanges", default=None)
    """Array containing the maximum range, in kilometers, for each provided waveform.

    The number of elements in this array must be equal to the value indicated in the
    numWaveforms field.
    """

    waveform_min_ranges: Optional[List[float]] = FieldInfo(alias="waveformMinRanges", default=None)
    """Array containing the minimum range, in kilometers, for each provided waveform.

    The number of elements in this array must be equal to the value indicated in the
    numWaveforms field.
    """

    waveform_pulse_widths: Optional[List[float]] = FieldInfo(alias="waveformPulseWidths", default=None)
    """Array containing the pulse width, in microseconds, for each provided waveform.

    The number of elements in this array must be equal to the value indicated in the
    numWaveforms field.
    """

    z1_max_range: Optional[float] = FieldInfo(alias="z1MaxRange", default=None)
    """Peformance zone-1 maximum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z1_min_range: Optional[float] = FieldInfo(alias="z1MinRange", default=None)
    """Peformance zone-1 minimum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z2_max_range: Optional[float] = FieldInfo(alias="z2MaxRange", default=None)
    """Peformance zone-2 maximum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """

    z2_min_range: Optional[float] = FieldInfo(alias="z2MinRange", default=None)
    """Peformance zone-2 minimum range, in kilometers.

    Note that the zones apply only to the PSR/Search radars.
    """


class SensorlimitsCollection(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    source: str
    """Source of the data."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the target sensor object."""

    id_sensor_limits: Optional[str] = FieldInfo(alias="idSensorLimits", default=None)
    """Unique identifier of the record, auto-generated by the system."""

    lower_left_azimuth_limit: Optional[float] = FieldInfo(alias="lowerLeftAzimuthLimit", default=None)
    """Leftmost or minimum lower azimuth within this limit.

    Interpreted according to site types as lower left azimuth limit elevation angle
    of axis of conical observation pattern. If the limit rectangle is parallel to
    the horizon, the upper and lower left azimuth limits would be equal. (degrees).
    """

    lower_left_elevation_limit: Optional[float] = FieldInfo(alias="lowerLeftElevationLimit", default=None)
    """Minimum or lower elevation within this limit.

    Interpreted according to site types as minimum elevation angle, constant
    elevation or fan beam centerline. (Degrees).
    """

    lower_right_azimuth_limit: Optional[float] = FieldInfo(alias="lowerRightAzimuthLimit", default=None)
    """Rightmost or maximum lower azimuth within this limit.

    Interpreted according to site types as 2nd lower azimuth limit elevation angle
    of axis of conical observation pattern. If the limit rectangle is parallel to
    the horizon, the upper and lower right azimuth limits would be equal. (degrees).
    """

    lower_right_elevation_limit: Optional[float] = FieldInfo(alias="lowerRightElevationLimit", default=None)
    """Minimum or lower right elevation within this limit.

    Interpreted according to site types as minimum right elevation angle, constant
    elevation or fan beam centerline. If the limit rectangle is parallel to the
    horizon, the left and right lower elevation limits would be equal. (Degrees).
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    upper_left_azimuth_limit: Optional[float] = FieldInfo(alias="upperLeftAzimuthLimit", default=None)
    """Leftmost or minimum upper azimuth within this sensor limit.

    Interpreted according to site types as beginning upper azimuth limit, left-hand
    upper boundary limit. If the limit rectangle is parallel to the horizon, the
    upper and lower left azimuth limits would be equal. (in degrees).
    """

    upper_left_elevation_limit: Optional[float] = FieldInfo(alias="upperLeftElevationLimit", default=None)
    """Maximum or upper elevation within this limit.

    Interpreted according to site types as maximum elevation angle, half the apex of
    conical observation pattern or star. (Degrees).
    """

    upper_right_azimuth_limit: Optional[float] = FieldInfo(alias="upperRightAzimuthLimit", default=None)
    """Rightmost or maximum upper azimuth within this limit.

    Interpreted according to site types as 2nd azimuth limit elevation angle of axis
    of conical observation pattern. If the limit rectangle is parallel to the
    horizon, the upper and lower right azimuth limits would be equal. (degrees).
    """

    upper_right_elevation_limit: Optional[float] = FieldInfo(alias="upperRightElevationLimit", default=None)
    """Maximum or upper right elevation within this limit.

    Interpreted according to site types as maximum rightmost elevation angle, half
    the apex of conical observation pattern or star. If the limit rectangle is
    parallel to the horizon, the left and right upper elevation limits would be
    equal. (Degrees).
    """


class SensorObservationType(BaseModel):
    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    type: Optional[str] = None
    """The observation measurement type produced by a sensor."""


class SensorStat(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    id_sensor: str = FieldInfo(alias="idSensor")
    """Unique ID of the parent sensor."""

    source: str
    """Source of the data."""

    id: Optional[str] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    last_ob_time: Optional[datetime] = FieldInfo(alias="lastObTime", default=None)
    """Time of last reported observation in ISO 8601 UTC with microsecond precision."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """
    Read-only time the row was updated in the database, set automatically by the
    system on update.
    """

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """
    Application user who last updated the row in the database, set by the system
    automatically and ignored on create/edit operations.
    """


class SensorType(BaseModel):
    id: Optional[int] = None
    """Unique identifier of the record, auto-generated by the system."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    type: Optional[str] = None
    """The specific sensor type and/or surveillance capability of this sensor."""


class SensorListResponse(BaseModel):
    classification_marking: str = FieldInfo(alias="classificationMarking")
    """Classification marking of the data in IC/CAPCO Portion-marked format."""

    data_mode: Literal["REAL", "TEST", "SIMULATED", "EXERCISE"] = FieldInfo(alias="dataMode")
    """Indicator of whether the data is EXERCISE, REAL, SIMULATED, or TEST data:

    EXERCISE:&nbsp;Data pertaining to a government or military exercise. The data
    may include both real and simulated data.

    REAL:&nbsp;Data collected or produced that pertains to real-world objects,
    events, and analysis.

    SIMULATED:&nbsp;Synthetic data generated by a model to mimic real-world
    datasets.

    TEST:&nbsp;Specific datasets used to evaluate compliance with specifications and
    requirements, and for validating technical, functional, and performance
    characteristics.
    """

    sensor_name: str = FieldInfo(alias="sensorName")
    """Unique name of this sensor."""

    source: str
    """Source of the data."""

    active: Optional[bool] = None
    """Optional flag indicating if the sensor is active."""

    af_id: Optional[str] = FieldInfo(alias="afId", default=None)
    """
    Optional US Air Force identifier for the sensor/ASR site, typically for air
    surveillance radar (ASR) sensors.
    """

    asr_type: Optional[str] = FieldInfo(alias="asrType", default=None)
    """The sensor type at the site. Optional field, intended primarily for ASRs."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Time the row was created in the database, auto-populated by the system."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """
    Application user who created the row in the database, auto-populated by the
    system.
    """

    data_control: Optional[str] = FieldInfo(alias="dataControl", default=None)
    """
    Optional dissemination control required for accessing data (e.g observations)
    produced by this sensor. This is typically a proprietary data owner control for
    commercial sensors.
    """

    entity: Optional[Entity] = None
    """
    An entity is a generic representation of any object within a space/SSA system
    such as sensors, on-orbit objects, RF Emitters, space craft buses, etc. An
    entity can have an operating unit, a location (if terrestrial), and statuses.
    """

    id_entity: Optional[str] = FieldInfo(alias="idEntity", default=None)
    """Unique identifier of the parent entity. idEntity is required for Put."""

    id_sensor: Optional[str] = FieldInfo(alias="idSensor", default=None)
    """Unique identifier of the record, auto-generated by the system."""

    origin: Optional[str] = None
    """
    Originating system or organization which produced the data, if different from
    the source. The origin may be different than the source if the source was a
    mediating system which forwarded the data on behalf of the origin system. If
    null, the source may be assumed to be the origin.
    """

    orig_network: Optional[str] = FieldInfo(alias="origNetwork", default=None)
    """
    The originating source network on which this record was created, auto-populated
    by the system.
    """

    sensorcharacteristics: Optional[List[Sensorcharacteristic]] = None
    """
    Collection of Sensorcharacteristics which define characteristics and
    capabilities of a sensor.
    """

    sensorlimits_collection: Optional[List[SensorlimitsCollection]] = FieldInfo(
        alias="sensorlimitsCollection", default=None
    )
    """
    Sensorlimits define 0 to many limits of a particular sensor in terms of
    observation coverage of on-orbit objects.
    """

    sensor_number: Optional[int] = FieldInfo(alias="sensorNumber", default=None)
    """Number assigned to this sensor.

    Since there is no authoritative numbering scheme, these numbers sometimes
    collide across sensors (especially commercial sensors). It is therefore not a
    unique identifier.
    """

    sensor_observation_type: Optional[SensorObservationType] = FieldInfo(alias="sensorObservationType", default=None)

    sensor_stats: Optional[List[SensorStat]] = FieldInfo(alias="sensorStats", default=None)
    """Collection of SensorStats which contain statistics of a sensor."""

    sensor_type: Optional[SensorType] = FieldInfo(alias="sensorType", default=None)

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)
    """Optional short name for the sensor."""
